# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aserto/authorizer/v2/api/identity_context.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/aserto/authorizer/v2/api/identity_context.proto\x12\x18\x61serto.authorizer.v2.api\"i\n\x0fIdentityContext\x12\x1a\n\x08identity\x18\x01 \x01(\tR\x08identity\x12:\n\x04type\x18\x02 \x01(\x0e\x32&.aserto.authorizer.v2.api.IdentityTypeR\x04type*o\n\x0cIdentityType\x12\x19\n\x15IDENTITY_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12IDENTITY_TYPE_NONE\x10\x01\x12\x15\n\x11IDENTITY_TYPE_SUB\x10\x02\x12\x15\n\x11IDENTITY_TYPE_JWT\x10\x03\x42\xfa\x01\n\x1c\x63om.aserto.authorizer.v2.apiB\x14IdentityContextProtoP\x01Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\xa2\x02\x04\x41\x41VA\xaa\x02\x18\x41serto.Authorizer.V2.Api\xca\x02\x18\x41serto\\Authorizer\\V2\\Api\xe2\x02$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\xea\x02\x1b\x41serto::Authorizer::V2::Apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aserto.authorizer.v2.api.identity_context_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.aserto.authorizer.v2.apiB\024IdentityContextProtoP\001Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\242\002\004AAVA\252\002\030Aserto.Authorizer.V2.Api\312\002\030Aserto\\Authorizer\\V2\\Api\342\002$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\352\002\033Aserto::Authorizer::V2::Api'
  _IDENTITYTYPE._serialized_start=184
  _IDENTITYTYPE._serialized_end=295
  _IDENTITYCONTEXT._serialized_start=77
  _IDENTITYCONTEXT._serialized_end=182
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PolicyContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INSTANCE_LABEL_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    DECISIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """policy name"""
    instance_label: builtins.str
    """label identifying the instance of the policy"""
    path: builtins.str
    """policy path aka package name"""
    @property
    def decisions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """list (1..N) of policy decisions (aka rules)"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        instance_label: builtins.str = ...,
        path: builtins.str = ...,
        decisions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["decisions", b"decisions", "instance_label", b"instance_label", "name", b"name", "path", b"path"]) -> None: ...

global___PolicyContext = PolicyContext



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Module(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    RAW_FIELD_NUMBER: builtins.int
    PACKAGE_PATH_FIELD_NUMBER: builtins.int
    AST_FIELD_NUMBER: builtins.int
    id: builtins.str
    raw: builtins.str
    package_path: builtins.str
    @property
    def ast(self) -> google.protobuf.struct_pb2.Value: ...
    def __init__(
        self,
        *,
        id: builtins.str | None = ...,
        raw: builtins.str | None = ...,
        package_path: builtins.str | None = ...,
        ast: google.protobuf.struct_pb2.Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_ast", b"_ast", "_id", b"_id", "_package_path", b"_package_path", "_raw", b"_raw", "ast", b"ast", "id", b"id", "package_path", b"package_path", "raw", b"raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_ast", b"_ast", "_id", b"_id", "_package_path", b"_package_path", "_raw", b"_raw", "ast", b"ast", "id", b"id", "package_path", b"package_path", "raw", b"raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_ast", b"_ast"]) -> typing_extensions.Literal["ast"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_id", b"_id"]) -> typing_extensions.Literal["id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_package_path", b"_package_path"]) -> typing_extensions.Literal["package_path"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_raw", b"_raw"]) -> typing_extensions.Literal["raw"] | None: ...

global___Module = Module



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aserto.authorizer.v2 import authorizer_pb2 as aserto_dot_authorizer_dot_v2_dot_authorizer__pb2


class AuthorizerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DecisionTree = channel.unary_unary(
                '/aserto.authorizer.v2.Authorizer/DecisionTree',
                request_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.DecisionTreeRequest.SerializeToString,
                response_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.DecisionTreeResponse.FromString,
                )
        self.Is = channel.unary_unary(
                '/aserto.authorizer.v2.Authorizer/Is',
                request_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.IsRequest.SerializeToString,
                response_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.IsResponse.FromString,
                )
        self.Query = channel.unary_unary(
                '/aserto.authorizer.v2.Authorizer/Query',
                request_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.QueryRequest.SerializeToString,
                response_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.QueryResponse.FromString,
                )
        self.Compile = channel.unary_unary(
                '/aserto.authorizer.v2.Authorizer/Compile',
                request_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.CompileRequest.SerializeToString,
                response_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.CompileResponse.FromString,
                )
        self.ListPolicies = channel.unary_unary(
                '/aserto.authorizer.v2.Authorizer/ListPolicies',
                request_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.ListPoliciesRequest.SerializeToString,
                response_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.ListPoliciesResponse.FromString,
                )
        self.GetPolicy = channel.unary_unary(
                '/aserto.authorizer.v2.Authorizer/GetPolicy',
                request_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.GetPolicyRequest.SerializeToString,
                response_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.GetPolicyResponse.FromString,
                )
        self.Info = channel.unary_unary(
                '/aserto.authorizer.v2.Authorizer/Info',
                request_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.InfoRequest.SerializeToString,
                response_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.InfoResponse.FromString,
                )


class AuthorizerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DecisionTree(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Is(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Query(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Compile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Info(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthorizerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DecisionTree': grpc.unary_unary_rpc_method_handler(
                    servicer.DecisionTree,
                    request_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.DecisionTreeRequest.FromString,
                    response_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.DecisionTreeResponse.SerializeToString,
            ),
            'Is': grpc.unary_unary_rpc_method_handler(
                    servicer.Is,
                    request_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.IsRequest.FromString,
                    response_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.IsResponse.SerializeToString,
            ),
            'Query': grpc.unary_unary_rpc_method_handler(
                    servicer.Query,
                    request_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.QueryRequest.FromString,
                    response_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.QueryResponse.SerializeToString,
            ),
            'Compile': grpc.unary_unary_rpc_method_handler(
                    servicer.Compile,
                    request_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.CompileRequest.FromString,
                    response_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.CompileResponse.SerializeToString,
            ),
            'ListPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPolicies,
                    request_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.ListPoliciesRequest.FromString,
                    response_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.ListPoliciesResponse.SerializeToString,
            ),
            'GetPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicy,
                    request_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.GetPolicyRequest.FromString,
                    response_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.GetPolicyResponse.SerializeToString,
            ),
            'Info': grpc.unary_unary_rpc_method_handler(
                    servicer.Info,
                    request_deserializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.InfoRequest.FromString,
                    response_serializer=aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.InfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aserto.authorizer.v2.Authorizer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Authorizer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DecisionTree(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aserto.authorizer.v2.Authorizer/DecisionTree',
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.DecisionTreeRequest.SerializeToString,
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.DecisionTreeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Is(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aserto.authorizer.v2.Authorizer/Is',
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.IsRequest.SerializeToString,
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.IsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Query(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aserto.authorizer.v2.Authorizer/Query',
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.QueryRequest.SerializeToString,
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.QueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Compile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aserto.authorizer.v2.Authorizer/Compile',
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.CompileRequest.SerializeToString,
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.CompileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aserto.authorizer.v2.Authorizer/ListPolicies',
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.ListPoliciesRequest.SerializeToString,
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.ListPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aserto.authorizer.v2.Authorizer/GetPolicy',
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.GetPolicyRequest.SerializeToString,
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.GetPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Info(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aserto.authorizer.v2.Authorizer/Info',
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.InfoRequest.SerializeToString,
            aserto_dot_authorizer_dot_v2_dot_authorizer__pb2.InfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from aserto.authorizer.v2.api.decision_logs_pb2 import (
    Decision,
    DecisionUser,
    DecisionPolicy,
)


from aserto.authorizer.v2.api.identity_context_pb2 import (
    IdentityType,
    IDENTITY_TYPE_UNKNOWN,
    IDENTITY_TYPE_NONE,
    IDENTITY_TYPE_SUB,
    IDENTITY_TYPE_JWT,

    IdentityContext,
)

from aserto.authorizer.v2.api.module_pb2 import Module
from aserto.authorizer.v2.api.policy_context_pb2 import PolicyContext

__all__ = [
    "Decision",
    "DecisionUser",
    "DecisionPolicy",

    "IdentityType",
    "IDENTITY_TYPE_UNKNOWN",
    "IDENTITY_TYPE_NONE",
    "IDENTITY_TYPE_SUB",
    "IDENTITY_TYPE_JWT",

    "IdentityContext",

    "Module",
    "PolicyContext",
]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import aserto.authorizer.v2.api.identity_context_pb2
import aserto.authorizer.v2.api.module_pb2
import aserto.authorizer.v2.api.policy_context_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PathSeparator:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PathSeparatorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PathSeparator.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PATH_SEPARATOR_UNKNOWN: _PathSeparator.ValueType  # 0
    """Value not set."""
    PATH_SEPARATOR_DOT: _PathSeparator.ValueType  # 1
    """Dot "." path separator"""
    PATH_SEPARATOR_SLASH: _PathSeparator.ValueType  # 2
    """Slash "/" path separtor"""

class PathSeparator(_PathSeparator, metaclass=_PathSeparatorEnumTypeWrapper): ...

PATH_SEPARATOR_UNKNOWN: PathSeparator.ValueType  # 0
"""Value not set."""
PATH_SEPARATOR_DOT: PathSeparator.ValueType  # 1
"""Dot "." path separator"""
PATH_SEPARATOR_SLASH: PathSeparator.ValueType  # 2
"""Slash "/" path separtor"""
global___PathSeparator = PathSeparator

class _TraceLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TraceLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TraceLevel.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRACE_LEVEL_UNKNOWN: _TraceLevel.ValueType  # 0
    """Value not set."""
    TRACE_LEVEL_OFF: _TraceLevel.ValueType  # 1
    """ExplainOffV1   ExplainModeV1 = "off" """
    TRACE_LEVEL_FULL: _TraceLevel.ValueType  # 2
    """ExplainFullV1  ExplainModeV1 = "full" """
    TRACE_LEVEL_NOTES: _TraceLevel.ValueType  # 3
    """ExplainNotesV1 ExplainModeV1 = "notes" """
    TRACE_LEVEL_FAILS: _TraceLevel.ValueType  # 4
    """ExplainFailsV1 ExplainModeV1 = "fails" """

class TraceLevel(_TraceLevel, metaclass=_TraceLevelEnumTypeWrapper): ...

TRACE_LEVEL_UNKNOWN: TraceLevel.ValueType  # 0
"""Value not set."""
TRACE_LEVEL_OFF: TraceLevel.ValueType  # 1
"""ExplainOffV1   ExplainModeV1 = "off" """
TRACE_LEVEL_FULL: TraceLevel.ValueType  # 2
"""ExplainFullV1  ExplainModeV1 = "full" """
TRACE_LEVEL_NOTES: TraceLevel.ValueType  # 3
"""ExplainNotesV1 ExplainModeV1 = "notes" """
TRACE_LEVEL_FAILS: TraceLevel.ValueType  # 4
"""ExplainFailsV1 ExplainModeV1 = "fails" """
global___TraceLevel = TraceLevel

class InfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InfoRequest = InfoRequest

class InfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    DATE_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    ARCH_FIELD_NUMBER: builtins.int
    version: builtins.str
    commit: builtins.str
    date: builtins.str
    os: builtins.str
    arch: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        commit: builtins.str = ...,
        date: builtins.str = ...,
        os: builtins.str = ...,
        arch: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arch", b"arch", "commit", b"commit", "date", b"date", "os", b"os", "version", b"version"]) -> None: ...

global___InfoResponse = InfoResponse

class GetPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_mask", b"field_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_mask", b"field_mask", "id", b"id"]) -> None: ...

global___GetPolicyRequest = GetPolicyRequest

class GetPolicyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> aserto.authorizer.v2.api.module_pb2.Module: ...
    def __init__(
        self,
        *,
        result: aserto.authorizer.v2.api.module_pb2.Module | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___GetPolicyResponse = GetPolicyResponse

class ListPoliciesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_MASK_FIELD_NUMBER: builtins.int
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_mask", b"field_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_mask", b"field_mask"]) -> None: ...

global___ListPoliciesRequest = ListPoliciesRequest

class ListPoliciesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[aserto.authorizer.v2.api.module_pb2.Module]: ...
    def __init__(
        self,
        *,
        result: collections.abc.Iterable[aserto.authorizer.v2.api.module_pb2.Module] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___ListPoliciesResponse = ListPoliciesResponse

class DecisionTreeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_CONTEXT_FIELD_NUMBER: builtins.int
    IDENTITY_CONTEXT_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def policy_context(self) -> aserto.authorizer.v2.api.policy_context_pb2.PolicyContext: ...
    @property
    def identity_context(self) -> aserto.authorizer.v2.api.identity_context_pb2.IdentityContext: ...
    @property
    def options(self) -> global___DecisionTreeOptions: ...
    @property
    def resource_context(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        policy_context: aserto.authorizer.v2.api.policy_context_pb2.PolicyContext | None = ...,
        identity_context: aserto.authorizer.v2.api.identity_context_pb2.IdentityContext | None = ...,
        options: global___DecisionTreeOptions | None = ...,
        resource_context: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity_context", b"identity_context", "options", b"options", "policy_context", b"policy_context", "resource_context", b"resource_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity_context", b"identity_context", "options", b"options", "policy_context", b"policy_context", "resource_context", b"resource_context"]) -> None: ...

global___DecisionTreeRequest = DecisionTreeRequest

class DecisionTreeOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_SEPARATOR_FIELD_NUMBER: builtins.int
    path_separator: global___PathSeparator.ValueType
    def __init__(
        self,
        *,
        path_separator: global___PathSeparator.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path_separator", b"path_separator"]) -> None: ...

global___DecisionTreeOptions = DecisionTreeOptions

class DecisionTreeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_ROOT_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    path_root: builtins.str
    @property
    def path(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        path_root: builtins.str = ...,
        path: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["path", b"path"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "path_root", b"path_root"]) -> None: ...

global___DecisionTreeResponse = DecisionTreeResponse

class IsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_CONTEXT_FIELD_NUMBER: builtins.int
    IDENTITY_CONTEXT_FIELD_NUMBER: builtins.int
    RESOURCE_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def policy_context(self) -> aserto.authorizer.v2.api.policy_context_pb2.PolicyContext: ...
    @property
    def identity_context(self) -> aserto.authorizer.v2.api.identity_context_pb2.IdentityContext: ...
    @property
    def resource_context(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        policy_context: aserto.authorizer.v2.api.policy_context_pb2.PolicyContext | None = ...,
        identity_context: aserto.authorizer.v2.api.identity_context_pb2.IdentityContext | None = ...,
        resource_context: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity_context", b"identity_context", "policy_context", b"policy_context", "resource_context", b"resource_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity_context", b"identity_context", "policy_context", b"policy_context", "resource_context", b"resource_context"]) -> None: ...

global___IsRequest = IsRequest

class Decision(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DECISION_FIELD_NUMBER: builtins.int
    IS_FIELD_NUMBER: builtins.int
    decision: builtins.str
    def __init__(
        self,
        *,
        decision: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["decision", b"decision", "is", b"is"]) -> None: ...

global___Decision = Decision

class IsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DECISIONS_FIELD_NUMBER: builtins.int
    @property
    def decisions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Decision]: ...
    def __init__(
        self,
        *,
        decisions: collections.abc.Iterable[global___Decision] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["decisions", b"decisions"]) -> None: ...

global___IsResponse = IsResponse

class QueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRICS_FIELD_NUMBER: builtins.int
    INSTRUMENT_FIELD_NUMBER: builtins.int
    TRACE_FIELD_NUMBER: builtins.int
    TRACE_SUMMARY_FIELD_NUMBER: builtins.int
    metrics: builtins.bool
    """default false"""
    instrument: builtins.bool
    """default false"""
    trace: global___TraceLevel.ValueType
    """default ExplainOffV1"""
    trace_summary: builtins.bool
    """default false"""
    def __init__(
        self,
        *,
        metrics: builtins.bool = ...,
        instrument: builtins.bool = ...,
        trace: global___TraceLevel.ValueType = ...,
        trace_summary: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instrument", b"instrument", "metrics", b"metrics", "trace", b"trace", "trace_summary", b"trace_summary"]) -> None: ...

global___QueryOptions = QueryOptions

class QueryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    POLICY_CONTEXT_FIELD_NUMBER: builtins.int
    IDENTITY_CONTEXT_FIELD_NUMBER: builtins.int
    RESOURCE_CONTEXT_FIELD_NUMBER: builtins.int
    query: builtins.str
    input: builtins.str
    @property
    def options(self) -> global___QueryOptions: ...
    @property
    def policy_context(self) -> aserto.authorizer.v2.api.policy_context_pb2.PolicyContext: ...
    @property
    def identity_context(self) -> aserto.authorizer.v2.api.identity_context_pb2.IdentityContext: ...
    @property
    def resource_context(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        query: builtins.str = ...,
        input: builtins.str = ...,
        options: global___QueryOptions | None = ...,
        policy_context: aserto.authorizer.v2.api.policy_context_pb2.PolicyContext | None = ...,
        identity_context: aserto.authorizer.v2.api.identity_context_pb2.IdentityContext | None = ...,
        resource_context: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_identity_context", b"_identity_context", "_options", b"_options", "_policy_context", b"_policy_context", "_resource_context", b"_resource_context", "identity_context", b"identity_context", "options", b"options", "policy_context", b"policy_context", "resource_context", b"resource_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_identity_context", b"_identity_context", "_options", b"_options", "_policy_context", b"_policy_context", "_resource_context", b"_resource_context", "identity_context", b"identity_context", "input", b"input", "options", b"options", "policy_context", b"policy_context", "query", b"query", "resource_context", b"resource_context"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_identity_context", b"_identity_context"]) -> typing_extensions.Literal["identity_context"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_options", b"_options"]) -> typing_extensions.Literal["options"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_policy_context", b"_policy_context"]) -> typing_extensions.Literal["policy_context"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_resource_context", b"_resource_context"]) -> typing_extensions.Literal["resource_context"] | None: ...

global___QueryRequest = QueryRequest

class CompileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    UNKNOWNS_FIELD_NUMBER: builtins.int
    DISABLE_INLINING_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    POLICY_CONTEXT_FIELD_NUMBER: builtins.int
    IDENTITY_CONTEXT_FIELD_NUMBER: builtins.int
    RESOURCE_CONTEXT_FIELD_NUMBER: builtins.int
    query: builtins.str
    input: builtins.str
    @property
    def unknowns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def disable_inlining(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def options(self) -> global___QueryOptions: ...
    @property
    def policy_context(self) -> aserto.authorizer.v2.api.policy_context_pb2.PolicyContext: ...
    @property
    def identity_context(self) -> aserto.authorizer.v2.api.identity_context_pb2.IdentityContext: ...
    @property
    def resource_context(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        query: builtins.str = ...,
        input: builtins.str = ...,
        unknowns: collections.abc.Iterable[builtins.str] | None = ...,
        disable_inlining: collections.abc.Iterable[builtins.str] | None = ...,
        options: global___QueryOptions | None = ...,
        policy_context: aserto.authorizer.v2.api.policy_context_pb2.PolicyContext | None = ...,
        identity_context: aserto.authorizer.v2.api.identity_context_pb2.IdentityContext | None = ...,
        resource_context: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_identity_context", b"_identity_context", "_options", b"_options", "_policy_context", b"_policy_context", "_resource_context", b"_resource_context", "identity_context", b"identity_context", "options", b"options", "policy_context", b"policy_context", "resource_context", b"resource_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_identity_context", b"_identity_context", "_options", b"_options", "_policy_context", b"_policy_context", "_resource_context", b"_resource_context", "disable_inlining", b"disable_inlining", "identity_context", b"identity_context", "input", b"input", "options", b"options", "policy_context", b"policy_context", "query", b"query", "resource_context", b"resource_context", "unknowns", b"unknowns"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_identity_context", b"_identity_context"]) -> typing_extensions.Literal["identity_context"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_options", b"_options"]) -> typing_extensions.Literal["options"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_policy_context", b"_policy_context"]) -> typing_extensions.Literal["policy_context"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_resource_context", b"_resource_context"]) -> typing_extensions.Literal["resource_context"] | None: ...

global___CompileRequest = CompileRequest

class CompileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    TRACE_FIELD_NUMBER: builtins.int
    TRACE_SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def metrics(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def trace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
    @property
    def trace_summary(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        result: google.protobuf.struct_pb2.Struct | None = ...,
        metrics: google.protobuf.struct_pb2.Struct | None = ...,
        trace: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        trace_summary: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metrics", b"metrics", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metrics", b"metrics", "result", b"result", "trace", b"trace", "trace_summary", b"trace_summary"]) -> None: ...

global___CompileResponse = CompileResponse

class QueryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    TRACE_FIELD_NUMBER: builtins.int
    TRACE_SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def response(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def metrics(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def trace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
    @property
    def trace_summary(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        response: google.protobuf.struct_pb2.Struct | None = ...,
        metrics: google.protobuf.struct_pb2.Struct | None = ...,
        trace: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        trace_summary: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metrics", b"metrics", "response", b"response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metrics", b"metrics", "response", b"response", "trace", b"trace", "trace_summary", b"trace_summary"]) -> None: ...

global___QueryResponse = QueryResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aserto/authorizer/v2/api/policy_context.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-aserto/authorizer/v2/api/policy_context.proto\x12\x18\x61serto.authorizer.v2.api\"|\n\rPolicyContext\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0einstance_label\x18\x02 \x01(\tR\rinstanceLabel\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x1c\n\tdecisions\x18\x04 \x03(\tR\tdecisionsB\xf8\x01\n\x1c\x63om.aserto.authorizer.v2.apiB\x12PolicyContextProtoP\x01Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\xa2\x02\x04\x41\x41VA\xaa\x02\x18\x41serto.Authorizer.V2.Api\xca\x02\x18\x41serto\\Authorizer\\V2\\Api\xe2\x02$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\xea\x02\x1b\x41serto::Authorizer::V2::Apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aserto.authorizer.v2.api.policy_context_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.aserto.authorizer.v2.apiB\022PolicyContextProtoP\001Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\242\002\004AAVA\252\002\030Aserto.Authorizer.V2.Api\312\002\030Aserto\\Authorizer\\V2\\Api\342\002$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\352\002\033Aserto::Authorizer::V2::Api'
  _POLICYCONTEXT._serialized_start=75
  _POLICYCONTEXT._serialized_end=199
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IdentityType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IdentityTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IdentityType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    IDENTITY_TYPE_UNKNOWN: _IdentityType.ValueType  # 0
    """Unknown, value not set, requests will fail with identity type not set error."""
    IDENTITY_TYPE_NONE: _IdentityType.ValueType  # 1
    """None, no explicit identity context set, equals anonymous."""
    IDENTITY_TYPE_SUB: _IdentityType.ValueType  # 2
    """Sub(ject), identity field contains an oAUTH subject."""
    IDENTITY_TYPE_JWT: _IdentityType.ValueType  # 3
    """JWT, identity field contains a JWT access token."""

class IdentityType(_IdentityType, metaclass=_IdentityTypeEnumTypeWrapper):
    """Identity types, describes the payload type of the identity field inside the IdentityContext message."""

IDENTITY_TYPE_UNKNOWN: IdentityType.ValueType  # 0
"""Unknown, value not set, requests will fail with identity type not set error."""
IDENTITY_TYPE_NONE: IdentityType.ValueType  # 1
"""None, no explicit identity context set, equals anonymous."""
IDENTITY_TYPE_SUB: IdentityType.ValueType  # 2
"""Sub(ject), identity field contains an oAUTH subject."""
IDENTITY_TYPE_JWT: IdentityType.ValueType  # 3
"""JWT, identity field contains a JWT access token."""
global___IdentityType = IdentityType

class IdentityContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    identity: builtins.str
    type: global___IdentityType.ValueType
    def __init__(
        self,
        *,
        identity: builtins.str = ...,
        type: global___IdentityType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "type", b"type"]) -> None: ...

global___IdentityContext = IdentityContext



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aserto/authorizer/v2/authorizer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from aserto.authorizer.v2.api import identity_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_identity__context__pb2
from aserto.authorizer.v2.api import policy_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_policy__context__pb2
from aserto.authorizer.v2.api import module_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%aserto/authorizer/v2/authorizer.proto\x12\x14\x61serto.authorizer.v2\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a google/protobuf/field_mask.proto\x1a/aserto/authorizer/v2/api/identity_context.proto\x1a-aserto/authorizer/v2/api/policy_context.proto\x1a%aserto/authorizer/v2/api/module.proto\"\r\n\x0bInfoRequest\"x\n\x0cInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x16\n\x06\x63ommit\x18\x02 \x01(\tR\x06\x63ommit\x12\x12\n\x04\x64\x61te\x18\x03 \x01(\tR\x04\x64\x61te\x12\x0e\n\x02os\x18\x04 \x01(\tR\x02os\x12\x12\n\x04\x61rch\x18\x05 \x01(\tR\x04\x61rch\"]\n\x10GetPolicyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"M\n\x11GetPolicyResponse\x12\x38\n\x06result\x18\x01 \x01(\x0b\x32 .aserto.authorizer.v2.api.ModuleR\x06result\"P\n\x13ListPoliciesRequest\x12\x39\n\nfield_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"P\n\x14ListPoliciesResponse\x12\x38\n\x06result\x18\x01 \x03(\x0b\x32 .aserto.authorizer.v2.api.ModuleR\x06result\"\xc4\x02\n\x13\x44\x65\x63isionTreeRequest\x12N\n\x0epolicy_context\x18\x01 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextR\rpolicyContext\x12T\n\x10identity_context\x18\x02 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextR\x0fidentityContext\x12\x43\n\x07options\x18\x03 \x01(\x0b\x32).aserto.authorizer.v2.DecisionTreeOptionsR\x07options\x12\x42\n\x10resource_context\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x0fresourceContext\"g\n\x13\x44\x65\x63isionTreeOptions\x12J\n\x0epath_separator\x18\x01 \x01(\x0e\x32#.aserto.authorizer.v2.PathSeparatorR\rpathSeparatorJ\x04\x08\x02\x10\x03\"f\n\x14\x44\x65\x63isionTreeResponse\x12\x1b\n\tpath_root\x18\x01 \x01(\tR\x08pathRoot\x12+\n\x04path\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x04pathJ\x04\x08\x02\x10\x03\"\xf5\x01\n\tIsRequest\x12N\n\x0epolicy_context\x18\x01 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextR\rpolicyContext\x12T\n\x10identity_context\x18\x02 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextR\x0fidentityContext\x12\x42\n\x10resource_context\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0fresourceContext\"6\n\x08\x44\x65\x63ision\x12\x1a\n\x08\x64\x65\x63ision\x18\x01 \x01(\tR\x08\x64\x65\x63ision\x12\x0e\n\x02is\x18\x02 \x01(\x08R\x02is\"J\n\nIsResponse\x12<\n\tdecisions\x18\x01 \x03(\x0b\x32\x1e.aserto.authorizer.v2.DecisionR\tdecisions\"\xa5\x01\n\x0cQueryOptions\x12\x18\n\x07metrics\x18\x01 \x01(\x08R\x07metrics\x12\x1e\n\ninstrument\x18\x02 \x01(\x08R\ninstrument\x12\x36\n\x05trace\x18\x03 \x01(\x0e\x32 .aserto.authorizer.v2.TraceLevelR\x05trace\x12#\n\rtrace_summary\x18\x04 \x01(\x08R\x0ctraceSummary\"\xbf\x03\n\x0cQueryRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x14\n\x05input\x18\x02 \x01(\tR\x05input\x12\x41\n\x07options\x18\x03 \x01(\x0b\x32\".aserto.authorizer.v2.QueryOptionsH\x00R\x07options\x88\x01\x01\x12S\n\x0epolicy_context\x18\x04 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextH\x01R\rpolicyContext\x88\x01\x01\x12Y\n\x10identity_context\x18\x05 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextH\x02R\x0fidentityContext\x88\x01\x01\x12G\n\x10resource_context\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructH\x03R\x0fresourceContext\x88\x01\x01\x42\n\n\x08_optionsB\x11\n\x0f_policy_contextB\x13\n\x11_identity_contextB\x13\n\x11_resource_context\"\x88\x04\n\x0e\x43ompileRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x14\n\x05input\x18\x02 \x01(\tR\x05input\x12\x1a\n\x08unknowns\x18\x03 \x03(\tR\x08unknowns\x12)\n\x10\x64isable_inlining\x18\x04 \x03(\tR\x0f\x64isableInlining\x12\x41\n\x07options\x18\x05 \x01(\x0b\x32\".aserto.authorizer.v2.QueryOptionsH\x00R\x07options\x88\x01\x01\x12S\n\x0epolicy_context\x18\x06 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextH\x01R\rpolicyContext\x88\x01\x01\x12Y\n\x10identity_context\x18\x07 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextH\x02R\x0fidentityContext\x88\x01\x01\x12G\n\x10resource_context\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructH\x03R\x0fresourceContext\x88\x01\x01\x42\n\n\x08_optionsB\x11\n\x0f_policy_contextB\x13\n\x11_identity_contextB\x13\n\x11_resource_context\"\xc9\x01\n\x0f\x43ompileResponse\x12/\n\x06result\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x06result\x12\x31\n\x07metrics\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x07metrics\x12-\n\x05trace\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructR\x05trace\x12#\n\rtrace_summary\x18\x04 \x03(\tR\x0ctraceSummary\"\xcb\x01\n\rQueryResponse\x12\x33\n\x08response\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x08response\x12\x31\n\x07metrics\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x07metrics\x12-\n\x05trace\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructR\x05trace\x12#\n\rtrace_summary\x18\x04 \x03(\tR\x0ctraceSummary*]\n\rPathSeparator\x12\x1a\n\x16PATH_SEPARATOR_UNKNOWN\x10\x00\x12\x16\n\x12PATH_SEPARATOR_DOT\x10\x01\x12\x18\n\x14PATH_SEPARATOR_SLASH\x10\x02*~\n\nTraceLevel\x12\x17\n\x13TRACE_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0fTRACE_LEVEL_OFF\x10\x01\x12\x14\n\x10TRACE_LEVEL_FULL\x10\x02\x12\x15\n\x11TRACE_LEVEL_NOTES\x10\x03\x12\x15\n\x11TRACE_LEVEL_FAILS\x10\x04\x32\xbc\r\n\nAuthorizer\x12\x91\x02\n\x0c\x44\x65\x63isionTree\x12).aserto.authorizer.v2.DecisionTreeRequest\x1a*.aserto.authorizer.v2.DecisionTreeResponse\"\xa9\x01\x82\xd3\xe4\x93\x02\x1f:\x01*\"\x1a/api/v2/authz/decisiontree\x92\x41\x80\x01\n\nauthorizer\x12\rDecision tree\x1a\x31Returns decision tree for given identity context.*\x18\x61uthorizer.decision_treeb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\x8f\x02\n\x02Is\x12\x1f.aserto.authorizer.v2.IsRequest\x1a .aserto.authorizer.v2.IsResponse\"\xc5\x01\x82\xd3\xe4\x93\x02\x15:\x01*\"\x10/api/v2/authz/is\x92\x41\xa6\x01\n\nauthorizer\x12\x0fIs (authorized)\x1a`Determines if identity context is authorized to access the resource guarded by the given policy.*\rauthorizer.isb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\xf3\x01\n\x05Query\x12\".aserto.authorizer.v2.QueryRequest\x1a#.aserto.authorizer.v2.QueryResponse\"\xa0\x01\x82\xd3\xe4\x93\x02\x18:\x01*\"\x13/api/v2/authz/query\x92\x41\x7f\n\nauthorizer\x12\x12Query (authorized)\x1a\x33\x45xecutes a rego query on the loaded policy runtime.*\x10\x61uthorizer.queryb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\x83\x02\n\x07\x43ompile\x12$.aserto.authorizer.v2.CompileRequest\x1a%.aserto.authorizer.v2.CompileResponse\"\xaa\x01\x82\xd3\xe4\x93\x02\x1a:\x01*\"\x15/api/v2/authz/compile\x92\x41\x86\x01\n\nauthorizer\x12\x14\x43ompile (authorized)\x1a\x36\x45xecutes a partial query on the loaded policy runtime.*\x12\x61uthorizer.compileb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\xf6\x01\n\x0cListPolicies\x12).aserto.authorizer.v2.ListPoliciesRequest\x1a*.aserto.authorizer.v2.ListPoliciesResponse\"\x8e\x01\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v2/policies\x92\x41s\n\nauthorizer\x12\rList Policies\x1a/Lists the policy modules for the policy bundle.*\rpolicies.listb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\xf4\x01\n\tGetPolicy\x12&.aserto.authorizer.v2.GetPolicyRequest\x1a\'.aserto.authorizer.v2.GetPolicyResponse\"\x95\x01\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v2/policies/{id=*/**}\x92\x41p\n\nauthorizer\x12\nGet Policy\x1a\x30Gets the policy modules for the given module Id.*\x0cpolicies.getb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\x9b\x01\n\x04Info\x12!.aserto.authorizer.v2.InfoRequest\x1a\".aserto.authorizer.v2.InfoResponse\"L\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v2/info\x92\x41\x35\n\x04Info\x12\x04Info\x1a\x1bReturn version information.*\x08info.getb\x00\x42\xcf\x02\n\x18\x63om.aserto.authorizer.v2B\x0f\x41uthorizerProtoP\x01ZCgithub.com/aserto-dev/go-authorizer/aserto/authorizer/v2;authorizer\xa2\x02\x03\x41\x41X\xaa\x02\x14\x41serto.Authorizer.V2\xca\x02\x14\x41serto\\Authorizer\\V2\xe2\x02 Aserto\\Authorizer\\V2\\GPBMetadata\xea\x02\x16\x41serto::Authorizer::V2\x92\x41j*\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonZ)\n\'\n\x10\x41uthorizerAPIKey\x12\x13\x08\x02\x1a\rauthorization \x02\x62\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aserto.authorizer.v2.authorizer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.aserto.authorizer.v2B\017AuthorizerProtoP\001ZCgithub.com/aserto-dev/go-authorizer/aserto/authorizer/v2;authorizer\242\002\003AAX\252\002\024Aserto.Authorizer.V2\312\002\024Aserto\\Authorizer\\V2\342\002 Aserto\\Authorizer\\V2\\GPBMetadata\352\002\026Aserto::Authorizer::V2\222Aj*\001\0022\020application/json:\020application/jsonZ)\n\'\n\020AuthorizerAPIKey\022\023\010\002\032\rauthorization \002b\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['DecisionTree']._options = None
  _AUTHORIZER.methods_by_name['DecisionTree']._serialized_options = b'\202\323\344\223\002\037:\001*\"\032/api/v2/authz/decisiontree\222A\200\001\n\nauthorizer\022\rDecision tree\0321Returns decision tree for given identity context.*\030authorizer.decision_treeb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Is']._options = None
  _AUTHORIZER.methods_by_name['Is']._serialized_options = b'\202\323\344\223\002\025:\001*\"\020/api/v2/authz/is\222A\246\001\n\nauthorizer\022\017Is (authorized)\032`Determines if identity context is authorized to access the resource guarded by the given policy.*\rauthorizer.isb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Query']._options = None
  _AUTHORIZER.methods_by_name['Query']._serialized_options = b'\202\323\344\223\002\030:\001*\"\023/api/v2/authz/query\222A\177\n\nauthorizer\022\022Query (authorized)\0323Executes a rego query on the loaded policy runtime.*\020authorizer.queryb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Compile']._options = None
  _AUTHORIZER.methods_by_name['Compile']._serialized_options = b'\202\323\344\223\002\032:\001*\"\025/api/v2/authz/compile\222A\206\001\n\nauthorizer\022\024Compile (authorized)\0326Executes a partial query on the loaded policy runtime.*\022authorizer.compileb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['ListPolicies']._options = None
  _AUTHORIZER.methods_by_name['ListPolicies']._serialized_options = b'\202\323\344\223\002\022\022\020/api/v2/policies\222As\n\nauthorizer\022\rList Policies\032/Lists the policy modules for the policy bundle.*\rpolicies.listb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['GetPolicy']._options = None
  _AUTHORIZER.methods_by_name['GetPolicy']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v2/policies/{id=*/**}\222Ap\n\nauthorizer\022\nGet Policy\0320Gets the policy modules for the given module Id.*\014policies.getb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Info']._options = None
  _AUTHORIZER.methods_by_name['Info']._serialized_options = b'\202\323\344\223\002\016\022\014/api/v2/info\222A5\n\004Info\022\004Info\032\033Return version information.*\010info.getb\000'
  _PATHSEPARATOR._serialized_start=3282
  _PATHSEPARATOR._serialized_end=3375
  _TRACELEVEL._serialized_start=3377
  _TRACELEVEL._serialized_end=3503
  _INFOREQUEST._serialized_start=340
  _INFOREQUEST._serialized_end=353
  _INFORESPONSE._serialized_start=355
  _INFORESPONSE._serialized_end=475
  _GETPOLICYREQUEST._serialized_start=477
  _GETPOLICYREQUEST._serialized_end=570
  _GETPOLICYRESPONSE._serialized_start=572
  _GETPOLICYRESPONSE._serialized_end=649
  _LISTPOLICIESREQUEST._serialized_start=651
  _LISTPOLICIESREQUEST._serialized_end=731
  _LISTPOLICIESRESPONSE._serialized_start=733
  _LISTPOLICIESRESPONSE._serialized_end=813
  _DECISIONTREEREQUEST._serialized_start=816
  _DECISIONTREEREQUEST._serialized_end=1140
  _DECISIONTREEOPTIONS._serialized_start=1142
  _DECISIONTREEOPTIONS._serialized_end=1245
  _DECISIONTREERESPONSE._serialized_start=1247
  _DECISIONTREERESPONSE._serialized_end=1349
  _ISREQUEST._serialized_start=1352
  _ISREQUEST._serialized_end=1597
  _DECISION._serialized_start=1599
  _DECISION._serialized_end=1653
  _ISRESPONSE._serialized_start=1655
  _ISRESPONSE._serialized_end=1729
  _QUERYOPTIONS._serialized_start=1732
  _QUERYOPTIONS._serialized_end=1897
  _QUERYREQUEST._serialized_start=1900
  _QUERYREQUEST._serialized_end=2347
  _COMPILEREQUEST._serialized_start=2350
  _COMPILEREQUEST._serialized_end=2870
  _COMPILERESPONSE._serialized_start=2873
  _COMPILERESPONSE._serialized_end=3074
  _QUERYRESPONSE._serialized_start=3077
  _QUERYRESPONSE._serialized_end=3280
  _AUTHORIZER._serialized_start=3506
  _AUTHORIZER._serialized_end=5230
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import aserto.authorizer.v2.authorizer_pb2
import grpc

class AuthorizerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    DecisionTree: grpc.UnaryUnaryMultiCallable[
        aserto.authorizer.v2.authorizer_pb2.DecisionTreeRequest,
        aserto.authorizer.v2.authorizer_pb2.DecisionTreeResponse,
    ]
    Is: grpc.UnaryUnaryMultiCallable[
        aserto.authorizer.v2.authorizer_pb2.IsRequest,
        aserto.authorizer.v2.authorizer_pb2.IsResponse,
    ]
    Query: grpc.UnaryUnaryMultiCallable[
        aserto.authorizer.v2.authorizer_pb2.QueryRequest,
        aserto.authorizer.v2.authorizer_pb2.QueryResponse,
    ]
    Compile: grpc.UnaryUnaryMultiCallable[
        aserto.authorizer.v2.authorizer_pb2.CompileRequest,
        aserto.authorizer.v2.authorizer_pb2.CompileResponse,
    ]
    ListPolicies: grpc.UnaryUnaryMultiCallable[
        aserto.authorizer.v2.authorizer_pb2.ListPoliciesRequest,
        aserto.authorizer.v2.authorizer_pb2.ListPoliciesResponse,
    ]
    GetPolicy: grpc.UnaryUnaryMultiCallable[
        aserto.authorizer.v2.authorizer_pb2.GetPolicyRequest,
        aserto.authorizer.v2.authorizer_pb2.GetPolicyResponse,
    ]
    Info: grpc.UnaryUnaryMultiCallable[
        aserto.authorizer.v2.authorizer_pb2.InfoRequest,
        aserto.authorizer.v2.authorizer_pb2.InfoResponse,
    ]

class AuthorizerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def DecisionTree(
        self,
        request: aserto.authorizer.v2.authorizer_pb2.DecisionTreeRequest,
        context: grpc.ServicerContext,
    ) -> aserto.authorizer.v2.authorizer_pb2.DecisionTreeResponse: ...
    @abc.abstractmethod
    def Is(
        self,
        request: aserto.authorizer.v2.authorizer_pb2.IsRequest,
        context: grpc.ServicerContext,
    ) -> aserto.authorizer.v2.authorizer_pb2.IsResponse: ...
    @abc.abstractmethod
    def Query(
        self,
        request: aserto.authorizer.v2.authorizer_pb2.QueryRequest,
        context: grpc.ServicerContext,
    ) -> aserto.authorizer.v2.authorizer_pb2.QueryResponse: ...
    @abc.abstractmethod
    def Compile(
        self,
        request: aserto.authorizer.v2.authorizer_pb2.CompileRequest,
        context: grpc.ServicerContext,
    ) -> aserto.authorizer.v2.authorizer_pb2.CompileResponse: ...
    @abc.abstractmethod
    def ListPolicies(
        self,
        request: aserto.authorizer.v2.authorizer_pb2.ListPoliciesRequest,
        context: grpc.ServicerContext,
    ) -> aserto.authorizer.v2.authorizer_pb2.ListPoliciesResponse: ...
    @abc.abstractmethod
    def GetPolicy(
        self,
        request: aserto.authorizer.v2.authorizer_pb2.GetPolicyRequest,
        context: grpc.ServicerContext,
    ) -> aserto.authorizer.v2.authorizer_pb2.GetPolicyResponse: ...
    @abc.abstractmethod
    def Info(
        self,
        request: aserto.authorizer.v2.authorizer_pb2.InfoRequest,
        context: grpc.ServicerContext,
    ) -> aserto.authorizer.v2.authorizer_pb2.InfoResponse: ...

def add_AuthorizerServicer_to_server(servicer: AuthorizerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import protoc_gen_openapiv2.options.openapiv2_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

OPENAPIV2_SWAGGER_FIELD_NUMBER: builtins.int
OPENAPIV2_OPERATION_FIELD_NUMBER: builtins.int
OPENAPIV2_SCHEMA_FIELD_NUMBER: builtins.int
OPENAPIV2_TAG_FIELD_NUMBER: builtins.int
OPENAPIV2_FIELD_FIELD_NUMBER: builtins.int
openapiv2_swagger: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, protoc_gen_openapiv2.options.openapiv2_pb2.Swagger]
"""ID assigned by protobuf-global-extension-registry@google.com for gRPC-Gateway project.

All IDs are the same, as assigned. It is okay that they are the same, as they extend
different descriptor messages.
"""
openapiv2_operation: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MethodOptions, protoc_gen_openapiv2.options.openapiv2_pb2.Operation]
"""ID assigned by protobuf-global-extension-registry@google.com for gRPC-Gateway project.

All IDs are the same, as assigned. It is okay that they are the same, as they extend
different descriptor messages.
"""
openapiv2_schema: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, protoc_gen_openapiv2.options.openapiv2_pb2.Schema]
"""ID assigned by protobuf-global-extension-registry@google.com for gRPC-Gateway project.

All IDs are the same, as assigned. It is okay that they are the same, as they extend
different descriptor messages.
"""
openapiv2_tag: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.ServiceOptions, protoc_gen_openapiv2.options.openapiv2_pb2.Tag]
"""ID assigned by protobuf-global-extension-registry@google.com for gRPC-Gateway project.

All IDs are the same, as assigned. It is okay that they are the same, as they extend
different descriptor messages.
"""
openapiv2_field: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, protoc_gen_openapiv2.options.openapiv2_pb2.JSONSchema]
"""ID assigned by protobuf-global-extension-registry@google.com for gRPC-Gateway project.

All IDs are the same, as assigned. It is okay that they are the same, as they extend
different descriptor messages.
"""



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import aserto.authorizer.v2.api.identity_context_pb2
import aserto.authorizer.v2.api.policy_context_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Decision(google.protobuf.message.Message):
    """represents a decision that an authorizer performed in the past"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class OutcomesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bool
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    OUTCOMES_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """unique id, replay a decision starting with this, also useful to de-dup"""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """UTC time when the decision was made"""
    path: builtins.str
    """Policy path used in decision"""
    @property
    def user(self) -> global___DecisionUser:
        """info about user for whom the decision as made"""
    @property
    def policy(self) -> global___DecisionPolicy:
        """info about policy used for the decision"""
    @property
    def outcomes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bool]:
        """outcome of the decisions specified in the policy context"""
    @property
    def resource(self) -> google.protobuf.struct_pb2.Struct:
        """the resource context used in a decision"""
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """annotations that may be added to a decision"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        path: builtins.str = ...,
        user: global___DecisionUser | None = ...,
        policy: global___DecisionPolicy | None = ...,
        outcomes: collections.abc.Mapping[builtins.str, builtins.bool] | None = ...,
        resource: google.protobuf.struct_pb2.Struct | None = ...,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["policy", b"policy", "resource", b"resource", "timestamp", b"timestamp", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "id", b"id", "outcomes", b"outcomes", "path", b"path", "policy", b"policy", "resource", b"resource", "timestamp", b"timestamp", "user", b"user"]) -> None: ...

global___Decision = Decision

class DecisionUser(google.protobuf.message.Message):
    """information about a user on behalf of whom a decision was made"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTEXT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    @property
    def context(self) -> aserto.authorizer.v2.api.identity_context_pb2.IdentityContext:
        """identity context used in the decision"""
    id: builtins.str
    """id of the user the identity resolved to"""
    email: builtins.str
    """convinience human-readable identifier"""
    def __init__(
        self,
        *,
        context: aserto.authorizer.v2.api.identity_context_pb2.IdentityContext | None = ...,
        id: builtins.str = ...,
        email: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "email", b"email", "id", b"id"]) -> None: ...

global___DecisionUser = DecisionUser

class DecisionPolicy(google.protobuf.message.Message):
    """information about a policy used in a decision"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTEXT_FIELD_NUMBER: builtins.int
    REGISTRY_SERVICE_FIELD_NUMBER: builtins.int
    REGISTRY_IMAGE_FIELD_NUMBER: builtins.int
    REGISTRY_TAG_FIELD_NUMBER: builtins.int
    REGISTRY_DIGEST_FIELD_NUMBER: builtins.int
    @property
    def context(self) -> aserto.authorizer.v2.api.policy_context_pb2.PolicyContext:
        """policy context used in the decision"""
    registry_service: builtins.str
    """registry service where policy was retrieved from (e.g. opcr.io)"""
    registry_image: builtins.str
    """image of the policy in the registry, including org (e.g. acmecorp/peoplefinder-abac)"""
    registry_tag: builtins.str
    """tag of the policy image (e.g. 0.8.2 or latest)"""
    registry_digest: builtins.str
    """digest of the policy image"""
    def __init__(
        self,
        *,
        context: aserto.authorizer.v2.api.policy_context_pb2.PolicyContext | None = ...,
        registry_service: builtins.str = ...,
        registry_image: builtins.str = ...,
        registry_tag: builtins.str = ...,
        registry_digest: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "registry_digest", b"registry_digest", "registry_image", b"registry_image", "registry_service", b"registry_service", "registry_tag", b"registry_tag"]) -> None: ...

global___DecisionPolicy = DecisionPolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aserto/authorizer/v2/api/decision_logs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from aserto.authorizer.v2.api import policy_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_policy__context__pb2
from aserto.authorizer.v2.api import identity_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_identity__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,aserto/authorizer/v2/api/decision_logs.proto\x12\x18\x61serto.authorizer.v2.api\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-aserto/authorizer/v2/api/policy_context.proto\x1a/aserto/authorizer/v2/api/identity_context.proto\"\xbd\x04\n\x08\x44\x65\x63ision\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12:\n\x04user\x18\x04 \x01(\x0b\x32&.aserto.authorizer.v2.api.DecisionUserR\x04user\x12@\n\x06policy\x18\x05 \x01(\x0b\x32(.aserto.authorizer.v2.api.DecisionPolicyR\x06policy\x12L\n\x08outcomes\x18\x06 \x03(\x0b\x32\x30.aserto.authorizer.v2.api.Decision.OutcomesEntryR\x08outcomes\x12\x33\n\x08resource\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructR\x08resource\x12U\n\x0b\x61nnotations\x18\x08 \x03(\x0b\x32\x33.aserto.authorizer.v2.api.Decision.AnnotationsEntryR\x0b\x61nnotations\x1a;\n\rOutcomesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"y\n\x0c\x44\x65\x63isionUser\x12\x43\n\x07\x63ontext\x18\x01 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextR\x07\x63ontext\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x14\n\x05\x65mail\x18\x03 \x01(\tR\x05\x65mail\"\xf1\x01\n\x0e\x44\x65\x63isionPolicy\x12\x41\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextR\x07\x63ontext\x12)\n\x10registry_service\x18\x02 \x01(\tR\x0fregistryService\x12%\n\x0eregistry_image\x18\x03 \x01(\tR\rregistryImage\x12!\n\x0cregistry_tag\x18\x04 \x01(\tR\x0bregistryTag\x12\'\n\x0fregistry_digest\x18\x05 \x01(\tR\x0eregistryDigestB\xf7\x01\n\x1c\x63om.aserto.authorizer.v2.apiB\x11\x44\x65\x63isionLogsProtoP\x01Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\xa2\x02\x04\x41\x41VA\xaa\x02\x18\x41serto.Authorizer.V2.Api\xca\x02\x18\x41serto\\Authorizer\\V2\\Api\xe2\x02$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\xea\x02\x1b\x41serto::Authorizer::V2::Apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aserto.authorizer.v2.api.decision_logs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.aserto.authorizer.v2.apiB\021DecisionLogsProtoP\001Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\242\002\004AAVA\252\002\030Aserto.Authorizer.V2.Api\312\002\030Aserto\\Authorizer\\V2\\Api\342\002$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\352\002\033Aserto::Authorizer::V2::Api'
  _DECISION_OUTCOMESENTRY._options = None
  _DECISION_OUTCOMESENTRY._serialized_options = b'8\001'
  _DECISION_ANNOTATIONSENTRY._options = None
  _DECISION_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _DECISION._serialized_start=234
  _DECISION._serialized_end=807
  _DECISION_OUTCOMESENTRY._serialized_start=684
  _DECISION_OUTCOMESENTRY._serialized_end=743
  _DECISION_ANNOTATIONSENTRY._serialized_start=745
  _DECISION_ANNOTATIONSENTRY._serialized_end=807
  _DECISIONUSER._serialized_start=809
  _DECISIONUSER._serialized_end=930
  _DECISIONPOLICY._serialized_start=933
  _DECISIONPOLICY._serialized_end=1174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/http.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15google/api/http.proto\x12\ngoogle.api\"y\n\x04Http\x12*\n\x05rules\x18\x01 \x03(\x0b\x32\x14.google.api.HttpRuleR\x05rules\x12\x45\n\x1f\x66ully_decode_reserved_expansion\x18\x02 \x01(\x08R\x1c\x66ullyDecodeReservedExpansion\"\xda\x02\n\x08HttpRule\x12\x1a\n\x08selector\x18\x01 \x01(\tR\x08selector\x12\x12\n\x03get\x18\x02 \x01(\tH\x00R\x03get\x12\x12\n\x03put\x18\x03 \x01(\tH\x00R\x03put\x12\x14\n\x04post\x18\x04 \x01(\tH\x00R\x04post\x12\x18\n\x06\x64\x65lete\x18\x05 \x01(\tH\x00R\x06\x64\x65lete\x12\x16\n\x05patch\x18\x06 \x01(\tH\x00R\x05patch\x12\x37\n\x06\x63ustom\x18\x08 \x01(\x0b\x32\x1d.google.api.CustomHttpPatternH\x00R\x06\x63ustom\x12\x12\n\x04\x62ody\x18\x07 \x01(\tR\x04\x62ody\x12#\n\rresponse_body\x18\x0c \x01(\tR\x0cresponseBody\x12\x45\n\x13\x61\x64\x64itional_bindings\x18\x0b \x03(\x0b\x32\x14.google.api.HttpRuleR\x12\x61\x64\x64itionalBindingsB\t\n\x07pattern\";\n\x11\x43ustomHttpPattern\x12\x12\n\x04kind\x18\x01 \x01(\tR\x04kind\x12\x12\n\x04path\x18\x02 \x01(\tR\x04pathB\xaa\x01\n\x0e\x63om.google.apiB\tHttpProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xf8\x01\x01\xa2\x02\x03GAX\xaa\x02\nGoogle.Api\xca\x02\nGoogle\\Api\xe2\x02\x16Google\\Api\\GPBMetadata\xea\x02\x0bGoogle::Apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.http_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\tHttpProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\370\001\001\242\002\003GAX\252\002\nGoogle.Api\312\002\nGoogle\\Api\342\002\026Google\\Api\\GPBMetadata\352\002\013Google::Api'
  _HTTP._serialized_start=37
  _HTTP._serialized_end=158
  _HTTPRULE._serialized_start=161
  _HTTPRULE._serialized_end=507
  _CUSTOMHTTPPATTERN._serialized_start=509
  _CUSTOMHTTPPATTERN._serialized_end=568
# @@protoc_insertion_point(module_scope)



from aserto.authorizer.v2.authorizer_pb2 import (
    PathSeparator,
    PATH_SEPARATOR_UNKNOWN,
    PATH_SEPARATOR_DOT,
    PATH_SEPARATOR_SLASH,

    TraceLevel,
    TRACE_LEVEL_UNKNOWN,
    TRACE_LEVEL_OFF,
    TRACE_LEVEL_FULL,
    TRACE_LEVEL_NOTES,
    TRACE_LEVEL_FAILS,

    GetPolicyRequest,
    GetPolicyResponse,
    ListPoliciesRequest,
    ListPoliciesResponse,
    DecisionTreeRequest,
    DecisionTreeOptions,
    DecisionTreeResponse,
    IsRequest,
    Decision,
    IsResponse,
    QueryOptions,
    QueryRequest,
    CompileRequest,
    CompileResponse,
    QueryResponse,
)

from aserto.authorizer.v2.authorizer_pb2_grpc import AuthorizerStub

__all__ = [
    "PathSeparator",
    "PATH_SEPARATOR_UNKNOWN",
    "PATH_SEPARATOR_DOT",
    "PATH_SEPARATOR_SLASH",

    "TraceLevel",
    "TRACE_LEVEL_UNKNOWN",
    "TRACE_LEVEL_OFF",
    "TRACE_LEVEL_FULL",
    "TRACE_LEVEL_NOTES",
    "TRACE_LEVEL_FAILS",

    "GetPolicyRequest",
    "GetPolicyResponse",
    "ListPoliciesRequest",
    "ListPoliciesResponse",
    "DecisionTreeRequest",
    "DecisionTreeOptions",
    "DecisionTreeResponse",
    "IsRequest",
    "Decision",
    "IsResponse",
    "QueryOptions",
    "QueryRequest",
    "CompileRequest",
    "CompileResponse",
    "QueryResponse",
]
